@@ -13,6 +13,18 @@ NAME
 #include "pngpriv.h"
 #include "sng.h"
 
+/* cope with API issues */
+#if PNG_LIBPNG_VER_MAJOR == 1
+  #if PNG_LIBPNG_VER_MINOR <= 2
+  #define TRANS_COLOR trans_values
+  #define TRANS_ALPHA trans
+  #endif
+  #if PNG_LIBPNG_VER_MINOR >= 4
+  #define TRANS_COLOR trans_color
+  #define TRANS_ALPHA trans_alpha
+  #endif
+#endif
+
 png_structp png_ptr;
 png_infop info_ptr;
 
@@ -727,8 +739,8 @@ static void dump_sCAL(FILE *fpout)
 	}
 #ifdef PNG_FLOATING_POINT_SUPPORTED
 #ifndef MNG_INTERFACE
-	fprintf(fpout, "    width:  %s\n", info_ptr->scal_s_width);
-	fprintf(fpout, "    height: %s\n", info_ptr->scal_s_height);
+	fprintf(fpout, "    width:  %g\n", info_ptr->scal_s_width);
+	fprintf(fpout, "    height: %g\n", info_ptr->scal_s_height);
 #else
 	fprintf(fpout, "    width:  %g\n", info_ptr->scal.pixel_width);
 	fprintf(fpout, "    height: %g\n", info_ptr->scal.pixel_height);
@@ -795,17 +807,17 @@ static void dump_tRNS(FILE *fpout)
 	fprintf(fpout, "tRNS {\n");
 	switch (info_ptr->color_type) {
 	case PNG_COLOR_TYPE_GRAY:
-	    fprintf(fpout, "    gray: %u;\n", info_ptr->trans_color.gray);
+	    fprintf(fpout, "    gray: %u;\n", info_ptr->TRANS_COLOR.gray);
 	    break;
 	case PNG_COLOR_TYPE_RGB:
 	    fprintf(fpout, "    red: %u; green: %u; blue: %u;\n",
-		    info_ptr->trans_color.red,
-		    info_ptr->trans_color.green,
-		    info_ptr->trans_color.blue);
+		    info_ptr->TRANS_COLOR.red,
+		    info_ptr->TRANS_COLOR.green,
+		    info_ptr->TRANS_COLOR.blue);
 	    break;
 	case PNG_COLOR_TYPE_PALETTE:
 	    for (i = 0; i < info_ptr->num_trans; i++)
-		fprintf(fpout, " %u", info_ptr->trans_alpha[i]);
+		fprintf(fpout, " %u", info_ptr->TRANS_ALPHA[i]);
 	    break;
 	case PNG_COLOR_TYPE_GRAY_ALPHA:
 	case PNG_COLOR_TYPE_RGB_ALPHA:
